@@ -15,10 +15,13 @@ Search::Xapian::LogicError -  The base class for exceptions indicating errors in
 use 5.006;
 use strict;
 use warnings;
-use Carp;
 
 require DynaLoader;
 
+# For compatibility with XS Search::Xapian < 1.2.3 which still threw strings
+# in some cases.
+use overload '""' => sub { "Exception: ".$_[0]->get_msg };
+
 use Search::Xapian::AssertionError;
 use Search::Xapian::InvalidArgumentError;
 use Search::Xapian::InvalidOperationError;
